package com.foreverwin.mesnac.common.mapper;

import org.springframework.stereotype.Repository;

import java.util.List;
import java.util.Map;

@Repository
public interface BoardMapper {
    //设备运行状态
    List<Map<String, Object>> resourceRunData(Map paramMap);
    //设备运行状态参数
    List<Map<String, Object>> resourceRunParamData(Map paramMap);
    //设备故障描述
    List<Map<String, Object>> resourceFaultDescription(Map paramMap);

    // 月完成数
    List<Map<String, Object>> monthPlanCompleteData(Map paramMap);
    // 月完成数
    List<Map<String, Object>> monthCompleteData(Map paramMap);
    // 月计划完成数和月完成数
    List<Map<String, Object>> monthCompleteAndPlanCompleteData(Map paramMap);

    // 合格率
    List<Map<String, Object>> percentOfPass(Map paramMap);

    // 车间设备近三天运行数
    List<Map<String, Object>> resourceRunDataThreeDay(Map paramMap);

    // 一次交检合格率
    List<Map<String, Object>> onceEspecially(Map paramMap);

    // 完工进度
    List<Map<String, Object>> scheduleOfCompletion(Map paramMap);

    // 异常处理情况
    List<Map<String, Object>> abnormalResolveData(Map paramMap);
    // 异常响应情况
    List<Map<String, Object>> abnormalContent(Map paramMap);

    // 焊接车间计划数
    List<Map<String, Object>> planDataFSW(Map paramMap);
    // 完成数
    List<Map<String, Object>> completeDataFSW(Map paramMap);
    // 焊接车间计划数、完成数
    List<Map<String, Object>> planAndCompleteDataFSW(Map paramMap);

    //综合看板
    // 设备异常提报数
    List<Map<String, Object>> resourceStatusQty(Map paramMap);
    // 设备各异常处理状态
    List<Map<String, Object>> resourceAbnormalInfo(Map paramMap);
    // 设备故障前三
    List<Map<String, Object>> resourceFaultThree(Map paramMap);
    // 达成率
    List<Map<String, Object>> completeRate(Map paramMap);

    // 设备运行数
    List<Map<String, Object>> resourceRunQtyAll(Map paramMap);
    List<Map<String, Object>> resourceQtyRun(Map paramMap);
    List<Map<String, Object>> resourceQtyFree(Map paramMap);
    List<Map<String, Object>> resourceQtyDow(Map paramMap);
    List<Map<String, Object>> resourceQtyAll(Map paramMap);

    // 异常类型数据
    List<Map<String, Object>> abnormalTypeQty(Map paramMap);
    // 异常详情
    List<Map<String, Object>> abnormalDataDetails(Map paramMap);

}
